<?php
/**
 * 파일: templates/admin-page.php
 * 설명: Autolinker 플러그인의 관리자 설정 페이지 템플릿
 */
?>
<div class="wrap">
    <h1>Autolinker 설정</h1>
    
    <?php
    // 수정 모드일 때 키워드 정보 가져오기
    $edit_mode = false;
    $editing_keyword = null;
    if (isset($_GET['action']) && $_GET['action'] === 'edit' && isset($_GET['id'])) {
        $edit_mode = true;
        $editing_keyword = $wpdb->get_row($wpdb->prepare(
            "SELECT * FROM {$wpdb->prefix}autolinker WHERE id = %d",
            intval($_GET['id'])
        ));
    }
    ?>
    
    <form method="post" action="<?php echo admin_url('admin-post.php'); ?>">
        <?php 
        if ($edit_mode) {
            wp_nonce_field('autolinker_edit_keyword', 'autolinker_nonce');
            echo '<input type="hidden" name="action" value="autolinker_edit_keyword">';
            echo '<input type="hidden" name="keyword_id" value="' . esc_attr($editing_keyword->id) . '">';
        } else {
            wp_nonce_field('autolinker_save_keyword', 'autolinker_nonce');
            echo '<input type="hidden" name="action" value="autolinker_save_keyword">';
        }
        ?>
        <table class="form-table">
            <tr>
                <th scope="row"><label for="keyword">키워드</label></th>
                <td>
                    <input name="keyword" type="text" id="keyword" 
                           value="<?php echo $edit_mode ? esc_attr($editing_keyword->keyword) : ''; ?>" 
                           class="regular-text" required>
                </td>
            </tr>
            <tr>
                <th scope="row"><label for="url">URL</label></th>
                <td>
                    <input name="url" type="url" id="url" 
                           value="<?php echo $edit_mode ? esc_url($editing_keyword->url) : ''; ?>" 
                           class="regular-text" required>
                </td>
            </tr>
            <tr>
				<th scope="row">링크 설정</th>
				<td>
					<label>
						<input name="open_new" type="checkbox" id="open_new"
							   <?php echo (!$edit_mode || ($edit_mode && $editing_keyword->open_new)) ? 'checked' : ''; ?>>
						새 창에서 열기
					</label>
				</td>
			</tr>
        </table>
        
        <?php 
        if ($edit_mode) {
            submit_button('키워드 수정', 'primary', 'edit_keyword');
            echo ' <a href="' . admin_url('admin.php?page=autolinker-settings') . '" class="button">취소</a>';
        } else {
            submit_button('키워드 추가', 'primary', 'save_keyword');
        }
        ?>
    </form>

    <h2>등록된 키워드 및 통계</h2>
    <div class="tablenav top">
		<div class="alignleft actions">
			<form method="get" action="<?php echo admin_url('admin.php'); ?>">
				<input type="hidden" name="page" value="autolinker-settings">
				<input type="search" 
					   name="search" 
					   value="<?php echo esc_attr($search_keyword); ?>" 
					   placeholder="키워드 검색..."
					   style="padding: 3px 8px;">
				<input type="submit" class="button" value="검색">
				<?php if (!empty($search_keyword)): ?>
					<a href="<?php echo admin_url('admin.php?page=autolinker-settings'); ?>" 
					   class="button">초기화</a>
				<?php endif; ?>
			</form>
		</div>
	</div>

<!-- 검색 결과가 없을 경우 메시지 표시 -->
<?php if (!empty($search_keyword) && empty($keywords)): ?>
    <div class="notice notice-info">
        <p>'<?php echo esc_html($search_keyword); ?>'에 대한 검색 결과가 없습니다.</p>
    </div>
<?php endif; ?>

	<table class="wp-list-table widefat fixed striped">
        <thead>
            <tr>
                <th>키워드</th>
                <th>URL</th>
                <th>링크 설정</th>
                <th>총 클릭수</th>
                <th>마지막 클릭</th>
                <th>등록일</th>
                <th>관리</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($keywords as $keyword): ?>
                <tr>
                    <td><?php echo esc_html($keyword->keyword); ?></td>
                    <td><?php echo esc_url($keyword->url); ?></td>
                    <td><?php echo $keyword->open_new ? '새 창' : '현재 창'; ?></td>
                    <td><?php echo intval($keyword->click_count); ?></td>
                    <td><?php echo $keyword->last_clicked ? esc_html($keyword->last_clicked) : '없음'; ?></td>
                    <td><?php echo esc_html($keyword->created_at); ?></td>
                    <td>
                        <a href="<?php echo add_query_arg(['page' => 'autolinker-settings', 'action' => 'edit', 'id' => $keyword->id]); ?>" 
                           class="button button-small">수정</a>
                        <form method="post" action="<?php echo admin_url('admin-post.php'); ?>" style="display:inline;">
                            <?php wp_nonce_field('autolinker_delete_keyword', 'autolinker_delete_nonce'); ?>
                            <input type="hidden" name="action" value="autolinker_delete_keyword">
                            <input type="hidden" name="keyword_id" value="<?php echo esc_attr($keyword->id); ?>">
                            <button type="submit" class="button button-small" 
                                    onclick="return confirm('정말 삭제하시겠습니까?');">삭제</button>
                        </form>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>

    <!-- 페이징 처리 수정 (검색어 파라미터 포함) -->
	<div class="tablenav bottom">
		<div class="tablenav-pages">
			<?php if ($total_pages > 1): ?>
				<span class="displaying-num">
					<?php printf( _n( '%s 개 항목', '%s 개 항목', $total_items ), number_format_i18n( $total_items ) ); ?>
				</span>
				<span class="pagination-links">
					<?php
					echo paginate_links(array(
						'base' => add_query_arg(array(
							'paged' => '%#%',
							'search' => $search_keyword
						)),
						'format' => '',
						'prev_text' => __('&laquo;'),
						'next_text' => __('&raquo;'),
						'total' => $total_pages,
						'current' => $current_page,
						'type' => 'plain'
					));
					?>
				</span>
			<?php endif; ?>
		</div>
	</div>